Crate zcfg

Crate zcfg 

Modules

__zcfg_example_pub_config

Macros

_define_config_inner
define_cfg
define_pub_cfg

Structs

CommaSeparatedCfgsDeprecated
Config
A configurable element in the associated module
ConfigInitializer
An initialization object that can statically set config objects.
ConfigMetadata
NoneableCfgDeprecated
STATIC_CONFIG_INITIALIZERS
The exhaustive list of config initializer objects.This list is populated by the constitutients of this binary before the main function (usingvery scary linker flags).
__ConfigValue
The inner config value.

Enums

InitErr

Traits

ConfigParseable
Any standard type which may be parsed from a string

Type Aliases

ParseErr